@@ -167,18 +167,20 @@ gst_mpeg_parse_class_init (GstMPEGParseClass * klass)
       gst_static_pad_template_get (&sink_factory));
 
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_MAX_SCR_GAP,
-      g_param_spec_int ("max_scr_gap", "Max SCR gap",
+      g_param_spec_int ("max-scr-gap", "Max SCR gap",
           "Maximum allowed gap between expected and actual "
           "SCR values. -1 means never adjust.", -1, G_MAXINT,
-          DEFAULT_MAX_SCR_GAP, G_PARAM_READWRITE));
+          DEFAULT_MAX_SCR_GAP, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_BYTE_OFFSET,
       g_param_spec_uint64 ("byte-offset", "Byte Offset",
           "Emit reached-offset signal when the byte offset is reached.",
-          0, G_MAXUINT64, G_MAXUINT64, G_PARAM_READWRITE));
+          0, G_MAXUINT64, G_MAXUINT64,
+          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_TIME_OFFSET,
       g_param_spec_uint64 ("time-offset", "Time Offset",
           "Time offset in the stream.",
-          0, G_MAXUINT64, G_MAXUINT64, G_PARAM_READABLE));
+          0, G_MAXUINT64, G_MAXUINT64,
+          G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 }
 
 static void
@@ -837,7 +839,7 @@ gst_mpeg_parse_chain (GstPad * pad, GstBuffer * buffer)
           ", total since SCR: %" G_GINT64_FORMAT ", br: %" G_GINT64_FORMAT
           ", next SCR: %" G_GINT64_FORMAT, size, bss, br, mpeg_parse->next_scr);
     }
-  } while (GST_FLOW_IS_SUCCESS (result));
+  } while (result == GST_FLOW_OK);
 
   if (result != GST_FLOW_OK) {
     GST_DEBUG_OBJECT (mpeg_parse, "flow: %s", gst_flow_get_name (result));
